@@ -3,5 +3,5 @@ import os
 absolute_path = os.path.abspath(__file__)
                                                             
 def main():                                                                   
-    cmd =['streamlit', 'run', os.path.dirname(absolute_path)+'/app.py', '--server.port','5000']                                                                 
+    cmd =['streamlit', 'run', os.path.dirname(absolute_path)+'/app.py', '--server.port','5000','--theme.base','dark']                                                                 
     subprocess.run(cmd)                                                    
